@@ -5,7 +5,7 @@ from scipy import signal, integrate
 from pykalman import UnscentedKalmanFilter
 from fbprophet import prophet_dataframe
 from tsaug import magnify,affine, crop, cross_sum , resample, reverse, trend, random_affine, random_crop, random_cross_sum, random_sidetrack, random_time_warp, random_magnify, random_jitter, random_trend
-
+import prophet
 
 
 def robust_scaler(df, drop=None,quantile_range=(25, 75) ):
@@ -210,7 +210,7 @@ def instantaneous_phases(band_signals, axis=0):
 
 
 def kalman_feat(df, col):
-      ukf = UnscentedKalmanFilter(lambda x, w: x + np.sin(w), lambda x, v: x + v, observation_covariance=0.1)
+  ukf = UnscentedKalmanFilter(lambda x, w: x + np.sin(w), lambda x, v: x + v, observation_covariance=0.1)
   (filtered_state_means, filtered_state_covariances) = ukf.filter(df[col])
   (smoothed_state_means, smoothed_state_covariances) = ukf.smooth(df[col])
   df["UKFSMOOTH"] = smoothed_state_means.flatten()
@@ -228,7 +228,7 @@ def perd_feat(df, column):
 # df = perd_feat(df,"Close")
 
 def fft_feat(df, col):
-      fft_df = np.fft.fft(np.asarray(df[col].tolist()))
+  fft_df = np.fft.fft(np.asarray(df[col].tolist()))
   fft_df = pd.DataFrame({'fft':fft_df})
   df['FFTABS'] = fft_df['fft'].apply(lambda x: np.abs(x)).values
   df['FFTANGLE'] = fft_df['fft'].apply(lambda x: np.angle(x)).values
@@ -279,7 +279,7 @@ def modify(df, column):
 # df_out = modify(df,"Close")
 
 def multiple_rolling(df, windows = [1,2], functions=["mean","std"], columns=None):
-      windows = [1+a for a in windows]
+  windows = [1+a for a in windows]
   if not columns:
     columns = df.columns.to_list()
   rolling_dfs = (df[columns].rolling(i)                                    # 1. Create window
@@ -298,7 +298,7 @@ def multiple_rolling(df, windows = [1,2], functions=["mean","std"], columns=None
 
 
 def multiple_lags(df, start=1, end=3,columns=None):
-      if not columns:
+  if not columns:
     columns = df.columns.to_list()
   lags = range(start, end+1)  # Just two lags for demonstration.
 
@@ -314,7 +314,7 @@ def multiple_lags(df, start=1, end=3,columns=None):
 
 
 def prophet_feat(df, col,drops, freq):
-      def prophet_dataframe(df): 
+  def prophet_dataframe(df): 
     df.columns = ['ds','y']
     return df
 
